library(MASS)  # in case it is not already loaded 
set.seed(101)
n <- 100000
X <- mvrnorm(n, mu=c(0,0), Sigma=matrix(c(1,.6,.6,1), ncol=2))

## some pretty colors
library(RColorBrewer)
k <- 11
my.cols <- rev(brewer.pal(k, "RdYlBu"))

## compute 2D kernel density, see MASS book, pp. 130-131
z <- kde2d(X[,1], X[,2], n=50)

MCMC = 30
par(mfrow=c(1,2))
source('~/Dropbox/Class/Astrostat2/MCMC.R')
source('~/Dropbox/Class/Astrostat2/Gibbs.R')
plot(X, xlab="X label", ylab="Y label",type="n")
points(THETA[1,],THETA[2,],pch=3,lwd=2)
lines(THETA[1,],THETA[2,],lwd=2)
contour(z, drawlabels=FALSE, nlevels=k, col=my.cols, add=TRUE,lwd=3)
plot(X, xlab="X label", ylab="Y label",type="n")
points(THETA2[1,],THETA2[2,],pch=5,lwd=2)
lines(THETA2[1,],THETA2[2,],lwd=2)
contour(z, drawlabels=FALSE, nlevels=k, col=my.cols, add=TRUE,lwd=3)

#abline(h=mean(X[,2]), v=mean(X[,1]), lwd=2)
#legend("topleft", paste("R=", round(cor(X)[1,2],2)), bty="n")



MCMC = 100
par(mfrow=c(1,2))
source('~/Dropbox/Class/Astrostat2/MCMC.R')
source('~/Dropbox/Class/Astrostat2/Gibbs.R')
plot(X, xlab="X label", ylab="Y label",type="n")
points(THETA[1,],THETA[2,],pch=3,lwd=2)
lines(THETA[1,],THETA[2,],lwd=2)
contour(z, drawlabels=FALSE, nlevels=k, col=my.cols, add=TRUE,lwd=3)
plot(X, xlab="X label", ylab="Y label",type="n")
points(THETA2[1,],THETA2[2,],pch=5,lwd=2)
lines(THETA2[1,],THETA2[2,],lwd=2)
contour(z, drawlabels=FALSE, nlevels=k, col=my.cols, add=TRUE,lwd=3)


MCMC = 10000
par(mfrow=c(1,2))
source('~/Dropbox/Class/Astrostat2/MCMC.R')
source('~/Dropbox/Class/Astrostat2/Gibbs.R')
plot(X, xlab="X label", ylab="Y label",type="n")
points(THETA[1,],THETA[2,],pch=3,lwd=2)
#lines(THETA[1,],THETA[2,],lwd=2)
contour(z, drawlabels=FALSE, nlevels=k, col=my.cols, add=TRUE,lwd=3)
plot(X, xlab="X label", ylab="Y label",type="n")
points(THETA2[1,],THETA2[2,],pch=5,lwd=2)
#lines(THETA2[1,],THETA2[2,],lwd=2)
contour(z, drawlabels=FALSE, nlevels=k, col=my.cols, add=TRUE,lwd=3)


############################################
############################################
Intrinsic Scatter Model
############################################
############################################
n = 100

X = runif(n,-3,3)

sig.i = abs(X)^2

sig0 = 1 # intrinsic scatter parameter 

y = 1 + X*2 +rnorm(n)*sqrt(sig.i+sig0)

plot(X,y)

source('~/Dropbox/Class/Astrostat2/instrinsic.MCMC.R')


par(mfrow=c(1,1))
plot(SIG,type="l",xlab="iteration",ylab="sigma")
plot(BETA[1,],type="l",xlab="iteration",ylab="beta0")
plot(BETA[2,],type="l",xlab="iteration",ylab="beta1")


y.post = matrix(0,MCMC,n)
for(iter in 1:MCMC){
  y.post[iter,] = BETA[1,iter] + BETA[2,iter]*X
}

q.L = rep(0,n)
q.U = rep(0,n)

for(i in 1:n){
  q.L[i] = quantile(y.post[,i],0.025)
  q.U[i] = quantile(y.post[,i],0.975)
}


y.pred= matrix(0,MCMC,n)
for(iter in 1:MCMC){
  y.pred[iter,] = BETA[1,iter] + BETA[2,iter]*X + rnorm(n)*sqrt(sig.i+SIG[iter])
}

q.L.pred = rep(0,n)
q.U.pred = rep(0,n)

for(i in 1:n){
  q.L.pred[i] = quantile(y.pred[,i],0.025)
  q.U.pred[i] = quantile(y.pred[,i],0.975)
}

plot(X,y)
lines(X, mean(BETA[1,])+mean(BETA[2,])*X,col="red",lwd=2)
points(X,q.L,col="gray",lwd=2,pch=4)
points(X,q.U,col="gray",lwd=2,pch=4)

points(X,q.L.pred,col="green",lwd=2,pch=4)
points(X,q.U.pred,col="green",lwd=2,pch=4)









